==> poi-scratchpad-3.9-sources.jar: org/apache/poi/hwpf/model/GenericPropertyNode.java <==
/* ====================================================================
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */

package org.apache.poi.hwpf.model;

import org.apache.poi.util.Internal;

@Internal
public final class GenericPropertyNode
  extends PropertyNode<GenericPropertyNode>
{
  public GenericPropertyNode(int start, int end, byte[] buf)
  {
    super(start, end, buf);
  }

  public byte[] getBytes()
  {
    return (byte[])_buf;
  }

    @Override
    public String toString()
    {
        return "GenericPropertyNode ["
                + getStart()
                + "; "
                + getEnd()
                + ") "
                + ( getBytes() != null ? getBytes().length + " byte(s)"
                        : "null" );
    }
}

==> poi-scratchpad-5.4.0-sources.jar: org/apache/poi/hwpf/model/GenericPropertyNode.java <==
/* ====================================================================
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */

package org.apache.poi.hwpf.model;

import org.apache.poi.util.Internal;

@Internal
public final class GenericPropertyNode extends PropertyNode<GenericPropertyNode> {

  public GenericPropertyNode(GenericPropertyNode other) {
    super(other);
  }

  public GenericPropertyNode(int start, int end, byte[] buf) {
    super(start, end, buf);
  }

  public byte[] getBytes()
  {
    return (byte[])_buf;
  }

    @Override
    public String toString()
    {
        return "GenericPropertyNode ["
                + getStart()
                + "; "
                + getEnd()
                + ") "
                + ( getBytes() != null ? getBytes().length + " byte(s)"
                        : "null" );
    }

  @Override
  public GenericPropertyNode copy() {
    return new GenericPropertyNode(this);
  }
}
